@@ -1,31 +1,43 @@
-from cnvrg.modules.base_module import CnvrgBase
-from cnvrg.helpers.apis_helper import download_file
-from cnvrg.modules.cnvrg_files import CnvrgFiles
-from cnvrg.modules import UnknownStsError
-from cnvrg.helpers.crypto_helpers import decrypt
+import os
+
 from typing import Dict, List
-from botocore.exceptions import ClientError
+from cnvrg.modules import UnknownStsError
+from cnvrg.modules.base_module import CnvrgBase
+from cnvrg.modules.cnvrg_files import CnvrgFiles
+from cnvrg.helpers.crypto_helpers import decrypt
+from cnvrg.helpers.apis_helper import download_file
 
 
 class BaseStorage(CnvrgBase):
     def __init__(self, element: CnvrgFiles, working_dir: str, sts_path: str):
         self.element = element
         self.working_dir = working_dir
+
+        self.sts_local_file = None
+        self.key = None
+        self.iv = None
         self.init_sts(sts_path)
+
         self.conflicts = []
 
     def init_sts(self, sts_path):
-        sts_file = download_file(sts_path, "/cnvrg/.cnvrg/.sts")
-        if not sts_file:
+        sts_local_file = os.path.join(os.path.expanduser("~"), ".cnvrg", ".sts")
+        sts_file = download_file(sts_path, sts_local_file)
+
+        if not sts_file or not os.path.exists(sts_file):
             raise UnknownStsError("Cant find sts")
-        with open(sts_file) as sts_content:
-            if not sts_content:
+
+        with open(sts_file) as content:
+            self.sts_local_file = sts_local_file
+            if not content:
                 raise UnknownStsError("Cant find sts")
-            self.key, self.iv, _ = sts_content.read().split("\n")
+            sts_content = content.read().split("\n")
+            self.key = sts_content[0]
+            self.iv = sts_content[1]
 
     def decrypt(self, text):
         return decrypt(self.key, self.iv, text)
 
     def decrypt_dict(self, props: Dict, keys: List = None):
-        return {k: decrypt(self.key, self.iv, v) if k in keys else v for k,v in props.items()}
+        return {k: decrypt(self.key, self.iv, v) if k in keys else v for k, v in props.items()}
 
